@@ -20,25 +20,19 @@ class pskr_listener:
         self.to_file = to_file
 
     def loop_for_time(self, time_seconds):
-        self.mqtt_cl.loop_start()
-        time.sleep(time_seconds)
-        self.mqtt_cl.loop_stop()
+        if(time_seconds > 3600):
+            self.mqtt_cl.loop_forever()
+        else:
+            self.mqtt_cl.loop_start()
+            time.sleep(time_seconds)
+            self.mqtt_cl.loop_stop()
 
     def loop_forever(self):
         self.mqtt_cl.loop_forever()
 
-    def get_decodes(self):    
-        return self.decodes
-
     def disconnect(self):
         self.mqtt_cl.disconnect()  
 
-    def purge_decodes(self, epoch):
-        n1 = len(self.decodes)
-        self.decodes = [d for d in self.decodes if int(d["t"]) >= epoch]
-        n2 = len(self.decodes)
-        print(f"Purged {n1-n2} decodes of {n1}")
-
     def subscribe(self, client, userdata, flags, reason_code, properties):
         # pskr/filter/v2/{band}/{mode}/{sendercall}/{receivercall}/{senderlocator}/{receiverlocator}/{sendercountry}/{receivercountry}
         print(f"Connected: {reason_code}")
@@ -66,21 +60,6 @@ class pskr_listener:
                 spot = f"{d['hc']}, {d['hl']}, {d['ha']}, {d['TxRx']}, {d['oc']}, {d['ol']}, {d['oa']}, {d['rp']}\n"
                 f.write(ebfm+spot)
                 f.flush()
-        else:
-            self.decodes.append(d)
-
-    def write_csv(self, decodes = None, filepath = ""):
-        if(decodes == None):
-            decodes = self.decodes
-        if(filepath == ""):
-            filepath =  f"{self.TxRx}_decodes.csv"
-        print(f"Writing {len(decodes)} decodes to {filepath}")
-        with open(filepath, "w") as f:
-            for d in decodes:
-                ebfm = f"{d['t']}, {d['b']}, {d['f']}, {d['md']}, "
-                spot = f"{d['hc']}, {d['hl']}, {d['ha']}, {d['TxRx']}, {d['oc']}, {d['ol']}, {d['oa']}, {d['rp']}\n"
-                f.write(ebfm+spot)
-            f.flush()
 
 
 
