@@ -8,6 +8,15 @@ import os
 import datetime
 import subprocess
 
+def get_cfg():
+    with open("hamplots.cfg","r") as f:
+        lines = f.readlines()
+    squares = lines[0]
+    bands = lines[1]
+    modes = lines[2]
+    return bands, modes, squares
+        
+
 def my_pcolor(ax, fig, rowheads, colheads, cells):
     nx=len(colheads)
     ny=len(rowheads)
@@ -21,6 +30,7 @@ def my_pcolor(ax, fig, rowheads, colheads, cells):
     ax.tick_params(top=True, bottom=False, labeltop=True, labelbottom=False)
     
 def start_rx(runsecs):
+    bands, modes, squares = get_cfg()
     print("Start Rx")
     rx_listener = hp.pskr_listener(mySquares, modes = myModes, bands = myBands, TxRx = "Rx", to_file = "Rx_decodes.csv")
     rx_listener.loop_for_time(runsecs);
@@ -28,6 +38,7 @@ def start_rx(runsecs):
     rx_listener.disconnect();
 
 def start_tx(runsecs):
+    bands, modes, squares = get_cfg()
     print("Start Tx")
     tx_listener = hp.pskr_listener(mySquares, modes = myModes, bands = myBands, TxRx = "Tx", to_file = "Tx_decodes.csv")
     tx_listener.loop_for_time(runsecs);
@@ -57,6 +68,7 @@ def check_plots_are_old(refresh_secs):
 def do_plots(timewin_start_offset_secs):
     print(f"Starting plots with time window {timewin_start_offset_secs} secs")
 
+    bands, modes, squares = get_cfg()
     for RxTx in ["Rx","Tx"]:
         decodes = hp.read_csv(f"{RxTx}_decodes.csv")
         if(not decodes):
@@ -71,7 +83,7 @@ def do_plots(timewin_start_offset_secs):
                 remote_calls = hp.cover_home_calls(remote_calls, homecall_reports)
 
                 # plot setup
-                timestr = datetime.datetime.now().strftime("%d/%m/%Y %H:%M UTC")
+                timestr = datetime.datetime.now().strftime("%d/%m/%Y %H:%M")
                 fig, axs = plt.subplots()
                 remote_action = "Transmitting" if RxTx == "Rx" else "Receiving"
                 home_entities = "Receivers'" if RxTx == "Rx" else "Transmitters'"
@@ -107,7 +119,6 @@ def do_plots(timewin_start_offset_secs):
 
 
 def get_args_and_run():
-    global mySquares, myBands, myModes
     
     from importlib.metadata import version
     try:
@@ -120,14 +131,8 @@ def get_args_and_run():
     parser.add_argument('--runsecs', type=str, default = "30", help = "Run mqtt listener for runsecs seconds")
     parser.add_argument('--plotwinsecs', type=str, default = "600", help = "Create plots covering now to now minus plotwinsecs seconds")
     parser.add_argument('--refreshsecs', type=str, default = "600", help = "Upload to github every refreshsecs seconds")
-    parser.add_argument('--bands', type=str, default = "40m, 20m, 15m, 10m, 2m", help = "Bands to scan")
-    parser.add_argument('--modes', type=str, default = "FT8, FT4", help = "Modes to scan")
-    parser.add_argument('--squares', type=str, default = "IO80,IO81,IO82,IO90,IO91,IO92,JO01,JO02,JO03", help = "Squares to define home")
-
+ 
     args = parser.parse_args()
-    mySquares = args.squares
-    myBands = args.bands
-    myModes = args.modes
 
     print(f"args.action = .{args.action}.")
     if(args.action == "start_rx"):
@@ -159,11 +164,13 @@ def get_args_and_run():
             time.sleep(refreshsecs)
             repo_dir = r"C:\Users\drala\Documents\Projects\GitHub\hamplots"
             subprocess.run(["hamplots", "do_plots", "--plotwinsecs", str(plotwinsecs)], cwd = repo_dir)
-            subprocess.run(["git", "add", "-f", "./plots/*.png ./plots/timestamp"], cwd=repo_dir)
+            subprocess.run(["git", "add", "-f", "./plots/*.png"], cwd=repo_dir)
+            subprocess.run(["git", "add", "-f", "./plots/timestamp"], cwd=repo_dir)
             subprocess.run(["git", "commit", "-m", "upload local data"], cwd=repo_dir)
             subprocess.run(["git", "pull"], cwd=repo_dir)
             subprocess.run(["git", "clean", "-f"], cwd=repo_dir)
             subprocess.run(["git", "push", "-f"], cwd=repo_dir)
+            subprocess.run(["git", "reset"], cwd=repo_dir)
 
 
 
